@@ -23,12 +23,12 @@ ffmpeg -version 2>&1
 # First video
 export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video1.mp4
 echo -n "[i] Encoding video #1... "
-lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video1.log
+lebiniou -c /usr/share/lebiniou/test/lebiniou.json -o mp4 -p $AUTOPKGTEST_TMP/lebiniou.pid -s -w 0 -N -E -W 0 -q > $AUTOPKGTEST_TMP/video1.log
 echo "done."
 # Second video
 export LEBINIOU_MP4_FILENAME=$AUTOPKGTEST_TMP/video2.mp4
 echo -n "[i] Encoding video #2... "
-lebiniou -c /usr/share/lebiniou/test/lebiniourc -N -E -W 0 -q > $AUTOPKGTEST_TMP/video2.log
+lebiniou -c /usr/share/lebiniou/test/lebiniou.json -o mp4 -p $AUTOPKGTEST_TMP/lebiniou.pid -s -w 0 -N -E -W 0 -q > $AUTOPKGTEST_TMP/video2.log
 echo "done."
 echo "[i] Generated videos and logs:"
 ls -lh $AUTOPKGTEST_TMP/*.mp4 $AUTOPKGTEST_TMP/*.log
